@@ -17,7 +17,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 package Qgoda;
-$Qgoda::VERSION = '0.9.5';
+$Qgoda::VERSION = '0.9.6';
 use common::sense;
 
 # FIXME! This assumes that we are a top-level package. Instead,
@@ -37,7 +37,6 @@ use Cwd;
 use Scalar::Util qw(reftype blessed);
 use AnyEvent;
 use AnyEvent::Loop;
-use AnyEvent::Filesys::Notify;
 use AnyEvent::Handle;
 use Symbol qw(gensym);
 use IPC::Open3 qw(open3);
@@ -59,6 +58,7 @@ use Qgoda::Util qw(empty strip_suffix interpolate normalize_path write_file
                    collect_defaults purify perl_class class2module trim
                    read_file);
 use Qgoda::PluginUtils qw(load_plugins);
+use Qgoda::AnyEvent::Notify;
 
 my $qgoda;
 
@@ -239,7 +239,7 @@ sub watch {
 
         $logger->debug(__x("waiting for changes in '{dir}'",
                            dir => $config->{srcdir}));
-        AnyEvent::Filesys::Notify->new(
+        Qgoda::AnyEvent::Notify->new(
             dirs => [$config->{srcdir}],
             interval => $config->{latency},
             parse_events => 1,
@@ -722,8 +722,6 @@ sub __filesysChangeFilter {
         return;
     }
 
-    return if $self->{__stop};
-
     if ($config->ignorePath($filename, 1)) {
         my $logger = $self->{__logger};
         $logger->debug(__x("changed file '{filename}' is ignored",
