@@ -18,7 +18,7 @@
 
 package TestSite;
 
-use strict;
+use common::sense;
 
 use File::Spec;
 use File::Path;
@@ -26,6 +26,7 @@ use File::Find;
 use File::Globstar::ListMatch;
 use YAML::XS;
 use Cwd;
+use Encode;
 
 use Qgoda;
 use Qgoda::Util qw(empty write_file);
@@ -110,12 +111,14 @@ sub __setupAssets {
 	foreach my $relpath (keys %{$self->{assets} || {}}) {
 		my $asset = $self->{assets}->{$relpath};
 		my $content = delete $asset->{content};
+		$content = '' if !defined $content;
 		if ($asset->{raw}) {
 			write_file $relpath, $content
 				or die "cannot write '$relpath': $!";
 		} else {
 			my $data = keys %$asset ? YAML::XS::Dump($asset) : "---\n";
 			$data .= "---\n$content";
+			Encode::_utf8_on($data);
 			write_file $relpath, $data
 				or die "cannot write '$relpath': $!";
 		}
@@ -161,4 +164,18 @@ sub tearDown {
 	return $self;
 }
 
+sub findArtefacts {
+	my ($self, $relpath) = @_;
+
+	my $path = File::Spec->catdir(File::Spec->curdir, '_site');
+	$path = File::Spec->catdir($path, $relpath) if !empty $relpath;
+
+	my @artefacts;
+	File::Find::find({
+		wanted => sub { push @artefacts, $File::Find::name if !-d $_ }
+	}, $path);
+
+	return wantarray ? sort @artefacts : scalar @artefacts;
+}
+
 1;
